@@ -20,6 +20,7 @@ import subprocess
 
 import flask
 import jinja2
+from oslo_config import cfg
 from oslo_log import log as logging
 import webob
 from werkzeug import exceptions
@@ -31,6 +32,7 @@ from octavia.common import constants as consts
 
 BUFFER = 100
 CHECK_SCRIPT_NAME = 'udp_check.sh'
+CONF = cfg.CONF
 KEEPALIVED_CHECK_SCRIPT_NAME = 'lvs_udp_check.sh'
 LOG = logging.getLogger(__name__)
 
@@ -76,7 +78,8 @@ class KeepalivedLvs(udp_listener_base.UdpListenerApiServerBase):
         # Active-Standby topology will create the directory below. So for
         # Single topology, it should not create the directory and the check
         # scripts for status change.
-        if not os.path.exists(util.keepalived_check_scripts_dir()):
+        if (CONF.controller_worker.loadbalancer_topology !=
+                consts.TOPOLOGY_ACTIVE_STANDBY):
             NEED_CHECK = False
 
         conf_file = util.keepalived_lvs_cfg_path(listener_id)
@@ -126,7 +129,9 @@ class KeepalivedLvs(udp_listener_base.UdpListenerApiServerBase):
                     keepalived_cmd=consts.KEEPALIVED_CMD,
                     keepalived_cfg=util.keepalived_lvs_cfg_path(listener_id),
                     amphora_nsname=consts.AMPHORA_NAMESPACE,
-                    amphora_netns=consts.AMP_NETNS_SVC_PREFIX
+                    amphora_netns=consts.AMP_NETNS_SVC_PREFIX,
+                    administrative_log_facility=(
+                        CONF.amphora_agent.administrative_log_facility),
                 )
                 text_file.write(text)
 
@@ -153,6 +158,9 @@ class KeepalivedLvs(udp_listener_base.UdpListenerApiServerBase):
             script_path = os.path.join(util.keepalived_check_scripts_dir(),
                                        KEEPALIVED_CHECK_SCRIPT_NAME)
             if not os.path.exists(script_path):
+                if not os.path.exists(util.keepalived_check_scripts_dir()):
+                    os.makedirs(util.keepalived_check_scripts_dir())
+
                 with os.fdopen(os.open(script_path, flags, stat.S_IEXEC),
                                'w') as script_file:
                     text = check_script_file_template.render(
@@ -161,6 +169,7 @@ class KeepalivedLvs(udp_listener_base.UdpListenerApiServerBase):
                         keepalived_lvs_pid_dir=util.keepalived_lvs_dir()
                     )
                     script_file.write(text)
+            util.vrrp_check_script_update(None, consts.AMP_ACTION_START)
 
         res = webob.Response(json={'message': 'OK'}, status=200)
         res.headers['ETag'] = stream.get_md5()
