@@ -81,19 +81,19 @@ class BaseOS(object):
         # interfaces and scripts.
         try:
             os.makedirs('/etc/netns/' + consts.AMPHORA_NAMESPACE)
+
+            shutil.copytree(
+                network_dir,
+                '/etc/netns/{netns}/{net_dir}'.format(
+                    netns=consts.AMPHORA_NAMESPACE,
+                    net_dir=netns_network_dir),
+                symlinks=True,
+                ignore=ignore)
         except OSError as e:
             # Raise the error if it's not "File exists" otherwise pass
             if e.errno != errno.EEXIST:
                 raise
 
-        shutil.copytree(
-            network_dir,
-            '/etc/netns/{netns}/{net_dir}'.format(
-                netns=consts.AMPHORA_NAMESPACE,
-                net_dir=netns_network_dir),
-            symlinks=True,
-            ignore=ignore)
-
     def write_vip_interface_file(self, interface_file_path,
                                  primary_interface, vip, ip, broadcast,
                                  netmask, gateway, mtu, vrrp_ip, vrrp_version,
@@ -117,7 +117,9 @@ class BaseOS(object):
                 interface=primary_interface,
                 vip=vip,
                 vip_ipv6=ip.version == 6,
-                prefix=utils.netmask_to_prefix(netmask),
+                # For ipv6 the netmask is already the prefix
+                prefix=(netmask if ip.version == 6
+                        else utils.netmask_to_prefix(netmask)),
                 broadcast=broadcast,
                 netmask=netmask,
                 gateway=gateway,
@@ -147,11 +149,12 @@ class BaseOS(object):
 
         with os.fdopen(os.open(interface_file_path, flags, mode),
                        'w') as text_file:
-            text = self._generate_network_file_text(netns_interface, fixed_ips,
-                                                    mtu, template_port)
+            text = self._generate_network_file_text(
+                netns_interface, fixed_ips, mtu, template_port)
             text_file.write(text)
 
-    def _generate_network_file_text(self, netns_interface, fixed_ips, mtu,
+    @classmethod
+    def _generate_network_file_text(cls, netns_interface, fixed_ips, mtu,
                                     template_port):
         text = ''
         if fixed_ips is None:
@@ -169,7 +172,7 @@ class BaseOS(object):
                     broadcast = network.broadcast_address.exploded
                     netmask = (network.prefixlen if ip.version == 6
                                else network.netmask.exploded)
-                    host_routes = self.get_host_routes(fixed_ip)
+                    host_routes = cls.get_host_routes(fixed_ip)
 
                 except ValueError:
                     return webob.Response(
@@ -184,7 +187,8 @@ class BaseOS(object):
                 text = '\n'.join([text, new_text])
         return text
 
-    def get_host_routes(self, fixed_ip):
+    @classmethod
+    def get_host_routes(cls, fixed_ip):
         host_routes = []
         for hr in fixed_ip.get('host_routes', []):
             network = ipaddress.ip_network(
@@ -194,13 +198,30 @@ class BaseOS(object):
             host_routes.append({'network': network, 'gw': hr['nexthop']})
         return host_routes
 
-    def _bring_if_up(self, interface, what):
+    @classmethod
+    def _bring_if_up(cls, interface, what, flush=True):
         # Note, we are not using pyroute2 for this as it is not /etc/netns
         # aware.
+        # Work around for bug:
+        # https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=845121
+        int_up = "ip netns exec {ns} ip link set {int} up".format(
+            ns=consts.AMPHORA_NAMESPACE, int=interface)
+        addr_flush = "ip netns exec {ns} ip addr flush {int}".format(
+            ns=consts.AMPHORA_NAMESPACE, int=interface)
+
         cmd = ("ip netns exec {ns} ifup {params}".format(
             ns=consts.AMPHORA_NAMESPACE, params=interface))
         try:
-            subprocess.check_output(cmd.split(), stderr=subprocess.STDOUT)
+            out = subprocess.check_output(int_up.split(),
+                                          stderr=subprocess.STDOUT)
+            LOG.debug(out)
+            if flush:
+                out = subprocess.check_output(addr_flush.split(),
+                                              stderr=subprocess.STDOUT)
+                LOG.debug(out)
+            out = subprocess.check_output(cmd.split(),
+                                          stderr=subprocess.STDOUT)
+            LOG.debug(out)
         except subprocess.CalledProcessError as e:
             LOG.error('Failed to ifup %s due to error: %s %s', interface, e,
                       e.output)
@@ -209,7 +230,8 @@ class BaseOS(object):
                     message='Error plugging {0}'.format(what),
                     details=e.output), status=500))
 
-    def _bring_if_down(self, interface):
+    @classmethod
+    def _bring_if_down(cls, interface):
         # Note, we are not using pyroute2 for this as it is not /etc/netns
         # aware.
         cmd = ("ip netns exec {ns} ifdown {params}".format(
@@ -220,13 +242,14 @@ class BaseOS(object):
             LOG.info('Ignoring failure to ifdown %s due to error: %s %s',
                      interface, e, e.output)
 
-    def bring_interfaces_up(self, ip, primary_interface, secondary_interface):
-        self._bring_if_down(primary_interface)
+    @classmethod
+    def bring_interfaces_up(cls, ip, primary_interface, secondary_interface):
+        cls._bring_if_down(primary_interface)
         if secondary_interface:
-            self._bring_if_down(secondary_interface)
-        self._bring_if_up(primary_interface, 'VIP')
+            cls._bring_if_down(secondary_interface)
+        cls._bring_if_up(primary_interface, 'VIP')
         if secondary_interface:
-            self._bring_if_up(secondary_interface, 'VIP')
+            cls._bring_if_up(secondary_interface, 'VIP', flush=False)
 
     def has_ifup_all(self):
         return True
@@ -334,24 +357,30 @@ class RH(BaseOS):
         name = self._map_package_name(package_name)
         return "rpm -q --queryformat %{{VERSION}} {name}".format(name=name)
 
-    def get_network_interface_file(self, interface):
+    @staticmethod
+    def _get_network_interface_file(prefix, interface):
         if CONF.amphora_agent.agent_server_network_file:
             return CONF.amphora_agent.agent_server_network_file
         if CONF.amphora_agent.agent_server_network_dir:
-            return os.path.join(CONF.amphora_agent.agent_server_network_dir,
-                                'ifcfg-' + interface)
-        network_dir = consts.RH_AMP_NET_DIR_TEMPLATE.format(
-            netns=consts.AMPHORA_NAMESPACE)
-        return os.path.join(network_dir, 'ifcfg-' + interface)
+            network_dir = CONF.amphora_agent.agent_server_network_dir
+        else:
+            network_dir = consts.RH_AMP_NET_DIR_TEMPLATE.format(
+                netns=consts.AMPHORA_NAMESPACE)
+        return os.path.join(network_dir, prefix + interface)
+
+    def get_network_interface_file(self, interface):
+        return self._get_network_interface_file('ifcfg-', interface)
 
     def get_alias_network_interface_file(self, interface):
         return self.get_network_interface_file(interface + ':0')
 
-    def get_static_routes_interface_file(self, interface):
-        return self.get_network_interface_file('route-' + interface)
+    def get_static_routes_interface_file(self, interface, version):
+        route = 'route6-' if version == 6 else 'route-'
+        return self._get_network_interface_file(route, interface)
 
-    def get_route_rules_interface_file(self, interface):
-        return self.get_network_interface_file('rule-' + interface)
+    def get_route_rules_interface_file(self, interface, version):
+        rule = 'rule6-' if version == 6 else 'rule-'
+        return self._get_network_interface_file(rule, interface)
 
     def get_network_path(self):
         return '/etc/sysconfig/network-scripts'
@@ -409,7 +438,8 @@ class RH(BaseOS):
                 render_host_routes, template_vip_alias)
 
         routes_interface_file_path = (
-            self.get_static_routes_interface_file(primary_interface))
+            self.get_static_routes_interface_file(primary_interface,
+                                                  ip.version))
         template_routes = j2_env.get_template(self.ROUTE_ETH_X_CONF)
 
         self.write_static_routes_interface_file(
@@ -420,7 +450,8 @@ class RH(BaseOS):
         if (CONF.controller_worker.loadbalancer_topology ==
                 consts.TOPOLOGY_SINGLE):
             route_rules_interface_file_path = (
-                self.get_route_rules_interface_file(primary_interface))
+                self.get_route_rules_interface_file(primary_interface,
+                                                    ip.version))
             template_rules = j2_env.get_template(self.RULE_ETH_X_CONF)
 
             self.write_static_routes_interface_file(
@@ -470,26 +501,43 @@ class RH(BaseOS):
 
         if fixed_ips:
             host_routes = []
+            host_routes_ipv6 = []
             for fixed_ip in fixed_ips:
-                host_routes.extend(self.get_host_routes(fixed_ip))
+                ip_addr = fixed_ip['ip_address']
+                ip = ipaddress.ip_address(ip_addr if isinstance(
+                    ip_addr, six.text_type) else six.u(ip_addr))
+                if ip.version == 6:
+                    host_routes_ipv6.extend(self.get_host_routes(fixed_ip))
+                else:
+                    host_routes.extend(self.get_host_routes(fixed_ip))
 
             routes_interface_file_path = (
-                self.get_static_routes_interface_file(netns_interface))
+                self.get_static_routes_interface_file(netns_interface, 4))
             template_routes = j2_env.get_template(self.ROUTE_ETH_X_CONF)
 
             self.write_static_routes_interface_file(
                 routes_interface_file_path, netns_interface,
                 host_routes, template_routes, None, None, None)
+
+            routes_interface_file_path_ipv6 = (
+                self.get_static_routes_interface_file(netns_interface, 6))
+            template_routes = j2_env.get_template(self.ROUTE_ETH_X_CONF)
+
+            self.write_static_routes_interface_file(
+                routes_interface_file_path_ipv6, netns_interface,
+                host_routes_ipv6, template_routes, None, None, None)
+
             self._write_ifup_ifdown_local_scripts_if_possible()
 
-    def bring_interfaces_up(self, ip, primary_interface, secondary_interface):
+    @classmethod
+    def bring_interfaces_up(cls, ip, primary_interface, secondary_interface):
         if ip.version == 4:
-            super(RH, self).bring_interfaces_up(
+            super(RH, cls).bring_interfaces_up(
                 ip, primary_interface, secondary_interface)
         else:
             # Secondary interface is not present in IPv6 configuration
-            self._bring_if_down(primary_interface)
-            self._bring_if_up(primary_interface, 'VIP')
+            cls._bring_if_down(primary_interface)
+            cls._bring_if_up(primary_interface, 'VIP')
 
     def has_ifup_all(self):
         return False
