@@ -294,6 +294,8 @@ class JinjaTemplater(object):
             pools.append(self._transform_pool(
                 pool, feature_compatibility, **kwargs))
         ret_value['pools'] = pools
+        policy_gen = (policy for policy in listener.l7policies if
+                      policy.provisioning_status != constants.PENDING_DELETE)
         if listener.default_pool:
             for pool in pools:
                 if pool['id'] == listener.default_pool.id:
@@ -302,7 +304,7 @@ class JinjaTemplater(object):
 
         l7policies = [self._transform_l7policy(
                       x, feature_compatibility, tls_certs)
-                      for x in listener.l7policies]
+                      for x in policy_gen]
         ret_value['l7policies'] = l7policies
         return ret_value
 
@@ -329,12 +331,16 @@ class JinjaTemplater(object):
             'crl_path': '',
             'tls_enabled': pool.tls_enabled
         }
+        members_gen = (mem for mem in pool.members if
+                       mem.provisioning_status != constants.PENDING_DELETE)
         members = [self._transform_member(x, feature_compatibility)
-                   for x in pool.members]
+                   for x in members_gen]
         ret_value['members'] = members
-        if pool.health_monitor:
+        health_mon = pool.health_monitor
+        if (health_mon and
+                health_mon.provisioning_status != constants.PENDING_DELETE):
             ret_value['health_monitor'] = self._transform_health_monitor(
-                pool.health_monitor, feature_compatibility)
+                health_mon, feature_compatibility)
         if pool.session_persistence:
             ret_value[
                 'session_persistence'] = self._transform_session_persistence(
@@ -418,7 +424,9 @@ class JinjaTemplater(object):
             'redirect_prefix': l7policy.redirect_prefix,
             'enabled': l7policy.enabled
         }
-        if l7policy.redirect_pool:
+        if (l7policy.redirect_pool and
+            l7policy.redirect_pool.provisioning_status !=
+                constants.PENDING_DELETE):
             kwargs = {}
             if tls_certs is not None and tls_certs.get(
                     l7policy.redirect_pool.id):
@@ -434,8 +442,10 @@ class JinjaTemplater(object):
             ret_value['redirect_http_code'] = l7policy.redirect_http_code
         else:
             ret_value['redirect_http_code'] = None
+        rule_gen = (rule for rule in l7policy.l7rules if rule.enabled and
+                    rule.provisioning_status != constants.PENDING_DELETE)
         l7rules = [self._transform_l7rule(x, feature_compatibility)
-                   for x in l7policy.l7rules if x.enabled]
+                   for x in rule_gen]
         ret_value['l7rules'] = l7rules
         return ret_value
 
