@@ -82,8 +82,8 @@ class NoopManager(object):
                   self.__class__.__name__, server_group_id)
         self.computeconfig[server_group_id] = (server_group_id, 'delete')
 
-    def attach_network_or_port(self, compute_id, network_id, ip_address=None,
-                               port_id=None):
+    def attach_network_or_port(self, compute_id, network_id=None,
+                               ip_address=None, port_id=None):
         LOG.debug("Compute %s no-op, attach_network_or_port compute_id %s,"
                   "network_id %s, ip_address %s, port_id %s",
                   self.__class__.__name__, compute_id,
@@ -145,8 +145,8 @@ class NoopComputeDriver(driver_base.ComputeBase):
     def delete_server_group(self, server_group_id):
         self.driver.delete_server_group(server_group_id)
 
-    def attach_network_or_port(self, compute_id, network_id, ip_address=None,
-                               port_id=None):
+    def attach_network_or_port(self, compute_id, network_id=None,
+                               ip_address=None, port_id=None):
         self.driver.attach_network_or_port(compute_id, network_id, ip_address,
                                            port_id)
 
