@@ -56,6 +56,9 @@ class AmpListenersUpdate(BaseAmphoraTask):
         # in a failover flow with both amps failing. Skip it and let
         # health manager fix it.
         try:
+            # Make sure we have a fresh load balancer object
+            loadbalancer = self.loadbalancer_repo.get(db_apis.get_session(),
+                                                      id=loadbalancer.id)
             self.amphora_driver.update_amphora_listeners(
                 loadbalancer, amphora, timeout_dict)
         except Exception as e:
@@ -75,6 +78,9 @@ class AmphoraIndexListenerUpdate(BaseAmphoraTask):
         # in a failover flow with both amps failing. Skip it and let
         # health manager fix it.
         try:
+            # Make sure we have a fresh load balancer object
+            loadbalancer = self.loadbalancer_repo.get(db_apis.get_session(),
+                                                      id=loadbalancer.id)
             self.amphora_driver.update_amphora_listeners(
                 loadbalancer, amphorae[amphora_index], timeout_dict)
         except Exception as e:
@@ -122,19 +128,20 @@ class ListenersStart(BaseAmphoraTask):
 class AmphoraIndexListenersReload(BaseAmphoraTask):
     """Task to reload all listeners on an amphora."""
 
-    def execute(self, loadbalancer, amphorae, amphora_index,
+    def execute(self, loadbalancer, amphora_index, amphorae,
                 timeout_dict=None):
         """Execute listener reload routines for listeners on an amphora."""
         if loadbalancer.listeners:
-            self.amphora_driver.reload(
-                loadbalancer, amphorae[amphora_index], timeout_dict)
-
-    def revert(self, loadbalancer, *args, **kwargs):
-        """Handle failed listeners reloads."""
-
-        LOG.warning("Reverting listener reload.")
-        for listener in loadbalancer.listeners:
-            self.task_utils.mark_listener_prov_status_error(listener.id)
+            try:
+                self.amphora_driver.reload(
+                    loadbalancer, amphorae[amphora_index], timeout_dict)
+            except Exception as e:
+                amphora_id = amphorae[amphora_index].id
+                LOG.warning('Failed to reload listeners on amphora %s. '
+                            'Skipping this amphora as it is failing to '
+                            'reload due to: %s', amphora_id, str(e))
+                self.amphora_repo.update(db_apis.get_session(), amphora_id,
+                                         status=constants.ERROR)
 
 
 class ListenerDelete(BaseAmphoraTask):
@@ -304,7 +311,7 @@ class AmphoraUpdateVRRPInterface(BaseAmphoraTask):
 class AmphoraIndexUpdateVRRPInterface(BaseAmphoraTask):
     """Task to get and update the VRRP interface device name from amphora."""
 
-    def execute(self, amphorae, amphora_index, timeout_dict=None):
+    def execute(self, amphora_index, amphorae, timeout_dict=None):
         amphora_id = amphorae[amphora_index].id
         try:
             interface = self.amphora_driver.get_interface_from_ip(
@@ -372,7 +379,7 @@ class AmphoraIndexVRRPUpdate(BaseAmphoraTask):
                       'to: %s', amphora_id, str(e))
             self.amphora_repo.update(db_apis.get_session(), amphora_id,
                                      status=constants.ERROR)
-
+            return
         LOG.debug("Uploaded VRRP configuration of amphora %s.", amphora_id)
 
 
@@ -403,8 +410,17 @@ class AmphoraIndexVRRPStart(BaseAmphoraTask):
     """
 
     def execute(self, amphora_index, amphorae, timeout_dict=None):
-        self.amphora_driver.start_vrrp_service(amphorae[amphora_index],
-                                               timeout_dict)
+        amphora_id = amphorae[amphora_index].id
+        try:
+            self.amphora_driver.start_vrrp_service(amphorae[amphora_index],
+                                                   timeout_dict)
+        except Exception as e:
+            LOG.error('Failed to start VRRP on amphora %s. '
+                      'Skipping this amphora as it is failing to start due '
+                      'to: %s', amphora_id, str(e))
+            self.amphora_repo.update(db_apis.get_session(), amphora_id,
+                                     status=constants.ERROR)
+            return
         LOG.debug("Started VRRP on amphora %s.", amphorae[amphora_index].id)
 
 
