@@ -103,6 +103,20 @@ def create_listener(listener_dict, lb_id):
 
     if 'client_authentication' not in listener_dict:
         listener_dict['client_authentication'] = constants.CLIENT_AUTH_NONE
+
+    if listener_dict.get('timeout_client_data') is None:
+        listener_dict['timeout_client_data'] = (
+            CONF.haproxy_amphora.timeout_client_data)
+    if listener_dict.get('timeout_member_connect') is None:
+        listener_dict['timeout_member_connect'] = (
+            CONF.haproxy_amphora.timeout_member_connect)
+    if listener_dict.get('timeout_member_data') is None:
+        listener_dict['timeout_member_data'] = (
+            CONF.haproxy_amphora.timeout_member_data)
+    if listener_dict.get('timeout_tcp_inspect') is None:
+        listener_dict['timeout_tcp_inspect'] = (
+            CONF.haproxy_amphora.timeout_tcp_inspect)
+
     return listener_dict
 
 
