@@ -22,6 +22,7 @@ from octavia.common import constants
 import octavia.common.context
 from octavia.common import data_models
 from octavia.common import exceptions
+from octavia.tests.common import constants as c_const
 from octavia.tests.functional.api.v2 import base
 
 
@@ -223,6 +224,58 @@ class TestL7Policy(base.BaseAPITest):
         self.assertIn((api_l7p_c.get('id'), api_l7p_c.get('action')),
                       policy_id_actions)
 
+    def test_get_all_unscoped_token(self):
+        project_id = uuidutils.generate_uuid()
+        lb1 = self.create_load_balancer(uuidutils.generate_uuid(), name='lb1',
+                                        project_id=project_id)
+        lb1_id = lb1.get('loadbalancer').get('id')
+        self.set_lb_status(lb1_id)
+        listener1 = self.create_listener(constants.PROTOCOL_HTTP, 80,
+                                         lb1_id)
+        listener1_id = listener1.get('listener').get('id')
+        self.set_lb_status(lb1_id)
+        pool1 = self.create_pool(lb1_id, constants.PROTOCOL_HTTP,
+                                 constants.LB_ALGORITHM_ROUND_ROBIN)
+        pool1_id = pool1.get('pool').get('id')
+        self.set_lb_status(lb1_id)
+        self.create_l7policy(
+            listener1_id,
+            constants.L7POLICY_ACTION_REJECT).get(self.root_tag)
+        self.set_lb_status(lb1_id)
+        self.create_l7policy(
+            listener1_id, constants.L7POLICY_ACTION_REDIRECT_TO_POOL,
+            position=2, redirect_pool_id=pool1_id).get(self.root_tag)
+        self.set_lb_status(lb1_id)
+        self.create_l7policy(
+            self.listener_id, constants.L7POLICY_ACTION_REDIRECT_TO_URL,
+            redirect_url='http://localhost/').get(self.root_tag)
+        self.set_lb_status(lb1_id)
+
+        auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
+        self.conf.config(group='api_settings',
+                         auth_strategy=constants.KEYSTONE)
+        with mock.patch.object(octavia.common.context.Context, 'project_id',
+                               None):
+            override_credentials = {
+                'service_user_id': None,
+                'user_domain_id': None,
+                'is_admin_project': True,
+                'service_project_domain_id': None,
+                'service_project_id': None,
+                'roles': ['load-balancer_member'],
+                'user_id': None,
+                'is_admin': False,
+                'service_user_domain_id': None,
+                'project_domain_id': None,
+                'service_roles': [],
+                'project_id': None}
+            with mock.patch(
+                    "oslo_context.context.RequestContext.to_policy_values",
+                    return_value=override_credentials):
+                result = self.get(self.L7POLICIES_PATH, status=403).json
+        self.conf.config(group='api_settings', auth_strategy=auth_strategy)
+        self.assertEqual(self.NOT_AUTHORIZED_BODY, result)
+
     def test_get_all_non_admin_global_observer(self):
         project_id = uuidutils.generate_uuid()
         lb1 = self.create_load_balancer(uuidutils.generate_uuid(), name='lb1',
@@ -770,21 +823,6 @@ class TestL7Policy(base.BaseAPITest):
             'redirect_pool_id': uuidutils.generate_uuid()}
         self.post(self.L7POLICIES_PATH, self._build_body(l7policy), status=404)
 
-    def test_bad_create_redirect_to_udp_pool(self):
-        udp_pool_id = self.create_pool(
-            self.lb_id,
-            constants.PROTOCOL_UDP,
-            constants.LB_ALGORITHM_ROUND_ROBIN).get('pool').get('id')
-        l7policy = {
-            'action': constants.L7POLICY_ACTION_REDIRECT_TO_POOL,
-            'listener_id': self.listener_id,
-            'redirect_pool_id': udp_pool_id}
-        res = self.post(self.L7POLICIES_PATH, self._build_body(l7policy),
-                        status=400, expect_errors=True)
-        expect_error_msg = ("Validation failure: %s protocol pool can not be "
-                            "assigned to l7policy.") % constants.PROTOCOL_UDP
-        self.assertEqual(expect_error_msg, res.json['faultstring'])
-
     def test_bad_create_redirect_to_url(self):
         l7policy = {'listener_id': self.listener_id,
                     'action': constants.L7POLICY_ACTION_REDIRECT_TO_URL,
@@ -935,27 +973,6 @@ class TestL7Policy(base.BaseAPITest):
             l7policy_id=api_l7policy.get('id')),
             self._build_body(new_l7policy), status=400)
 
-    def test_bad_update_redirect_to_udp_pool(self):
-        api_l7policy = self.create_l7policy(self.listener_id,
-                                            constants.L7POLICY_ACTION_REJECT,
-                                            ).get(self.root_tag)
-        self.set_lb_status(self.lb_id)
-        udp_pool_id = self.create_pool(
-            self.lb_id,
-            constants.PROTOCOL_UDP,
-            constants.LB_ALGORITHM_ROUND_ROBIN).get('pool').get('id')
-        self.set_lb_status(self.lb_id)
-        new_l7policy = {
-            'action': constants.L7POLICY_ACTION_REDIRECT_TO_POOL,
-            'redirect_pool_id': udp_pool_id}
-        res = self.put(self.L7POLICY_PATH.format(
-            l7policy_id=api_l7policy.get('id')),
-            self._build_body(new_l7policy),
-            status=400, expect_errors=True)
-        expect_error_msg = ("Validation failure: %s protocol pool can not be "
-                            "assigned to l7policy.") % constants.PROTOCOL_UDP
-        self.assertEqual(expect_error_msg, res.json['faultstring'])
-
     def test_bad_update_redirect_to_url(self):
         api_l7policy = self.create_l7policy(self.listener_id,
                                             constants.L7POLICY_ACTION_REJECT,
@@ -1298,3 +1315,118 @@ class TestL7Policy(base.BaseAPITest):
         self.delete(self.L7POLICY_PATH.format(
                     l7policy_id=l7policy.get('id')),
                     status=404)
+
+    @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
+    def test_listener_pool_protocol_map_post(self, mock_cert_data):
+        cert = data_models.TLSContainer(certificate='cert')
+        mock_cert_data.return_value = {'sni_certs': [cert]}
+        valid_map = constants.VALID_LISTENER_POOL_PROTOCOL_MAP
+        port = 1
+        l7policy = {'action': constants.L7POLICY_ACTION_REDIRECT_TO_POOL}
+        for listener_proto in valid_map:
+            for pool_proto in valid_map[listener_proto]:
+                port = port + 1
+                opts = {}
+                if listener_proto == constants.PROTOCOL_TERMINATED_HTTPS:
+                    opts['sni_container_refs'] = [uuidutils.generate_uuid()]
+                listener = self.create_listener(
+                    listener_proto, port, self.lb_id, **opts).get('listener')
+                self.set_object_status(self.lb_repo, self.lb_id)
+                pool = self.create_pool(
+                    self.lb_id, pool_proto,
+                    constants.LB_ALGORITHM_ROUND_ROBIN).get('pool')
+
+                l7policy['listener_id'] = listener.get('id')
+                l7policy['redirect_pool_id'] = pool.get('id')
+                self.set_object_status(self.lb_repo, self.lb_id)
+                self.post(self.L7POLICIES_PATH,
+                          self._build_body(l7policy), status=201)
+                self.set_object_status(self.lb_repo, self.lb_id)
+
+        invalid_map = c_const.INVALID_LISTENER_POOL_PROTOCOL_MAP
+        port = 100
+        for listener_proto in invalid_map:
+            opts = {}
+            if listener_proto == constants.PROTOCOL_TERMINATED_HTTPS:
+                opts['sni_container_refs'] = [uuidutils.generate_uuid()]
+            listener = self.create_listener(
+                listener_proto, port, self.lb_id, **opts).get('listener')
+            self.set_object_status(self.lb_repo, self.lb_id)
+            port = port + 1
+            for pool_proto in invalid_map[listener_proto]:
+                pool = self.create_pool(
+                    self.lb_id, pool_proto,
+                    constants.LB_ALGORITHM_ROUND_ROBIN).get('pool')
+                self.set_object_status(self.lb_repo, self.lb_id)
+
+                l7policy['listener_id'] = listener.get('id')
+                l7policy['redirect_pool_id'] = pool.get('id')
+                expect_error_msg = ("Validation failure: The pool protocol "
+                                    "'%s' is invalid while the listener "
+                                    "protocol is '%s'.") % (pool_proto,
+                                                            listener_proto)
+                res = self.post(self.L7POLICIES_PATH,
+                                self._build_body(l7policy), status=400)
+                self.assertEqual(expect_error_msg, res.json['faultstring'])
+                self.assert_correct_status(lb_id=self.lb_id)
+
+    @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
+    def test_listener_pool_protocol_map_put(self, mock_cert_data):
+        cert = data_models.TLSContainer(certificate='cert')
+        mock_cert_data.return_value = {'sni_certs': [cert]}
+        valid_map = constants.VALID_LISTENER_POOL_PROTOCOL_MAP
+        port = 1
+        new_l7policy = {'action': constants.L7POLICY_ACTION_REDIRECT_TO_POOL}
+        for listener_proto in valid_map:
+            for pool_proto in valid_map[listener_proto]:
+                port = port + 1
+                opts = {}
+                if listener_proto == constants.PROTOCOL_TERMINATED_HTTPS:
+                    opts['sni_container_refs'] = [uuidutils.generate_uuid()]
+                listener = self.create_listener(
+                    listener_proto, port, self.lb_id, **opts).get('listener')
+                self.set_object_status(self.lb_repo, self.lb_id)
+                pool = self.create_pool(
+                    self.lb_id, pool_proto,
+                    constants.LB_ALGORITHM_ROUND_ROBIN).get('pool')
+                self.set_object_status(self.lb_repo, self.lb_id)
+                l7policy = self.create_l7policy(
+                    listener.get('id'),
+                    constants.L7POLICY_ACTION_REJECT).get(self.root_tag)
+                self.set_object_status(self.lb_repo, self.lb_id)
+                new_l7policy['redirect_pool_id'] = pool.get('id')
+
+                self.put(
+                    self.L7POLICY_PATH.format(l7policy_id=l7policy.get('id')),
+                    self._build_body(new_l7policy), status=200)
+                self.set_object_status(self.lb_repo, self.lb_id)
+
+        invalid_map = c_const.INVALID_LISTENER_POOL_PROTOCOL_MAP
+        port = 100
+        for listener_proto in invalid_map:
+            opts = {}
+            if listener_proto == constants.PROTOCOL_TERMINATED_HTTPS:
+                opts['sni_container_refs'] = [uuidutils.generate_uuid()]
+            listener = self.create_listener(
+                listener_proto, port, self.lb_id, **opts).get('listener')
+            self.set_object_status(self.lb_repo, self.lb_id)
+            port = port + 1
+            for pool_proto in invalid_map[listener_proto]:
+                pool = self.create_pool(
+                    self.lb_id, pool_proto,
+                    constants.LB_ALGORITHM_ROUND_ROBIN).get('pool')
+                self.set_object_status(self.lb_repo, self.lb_id)
+                l7policy = self.create_l7policy(
+                    listener.get('id'),
+                    constants.L7POLICY_ACTION_REJECT).get(self.root_tag)
+                self.set_object_status(self.lb_repo, self.lb_id)
+                new_l7policy['redirect_pool_id'] = pool.get('id')
+                expect_error_msg = ("Validation failure: The pool protocol "
+                                    "'%s' is invalid while the listener "
+                                    "protocol is '%s'.") % (pool_proto,
+                                                            listener_proto)
+                res = self.put(self.L7POLICY_PATH.format(
+                    l7policy_id=l7policy.get('id')),
+                    self._build_body(new_l7policy), status=400)
+                self.assertEqual(expect_error_msg, res.json['faultstring'])
+                self.assert_correct_status(lb_id=self.lb_id)
