@@ -499,8 +499,9 @@ class TestAmphoraDriverTasks(base.TestCase):
         amphora_update_vrrp_interface_obj = (
             amphora_driver_tasks.AmphoraUpdateVRRPInterface())
         amphora_update_vrrp_interface_obj.execute(_LB_mock)
-        mock_driver.get_vrrp_interface.assert_called_once_with(
-            _amphora_mock, timeout_dict=timeout_dict)
+        mock_driver.get_interface_from_ip.assert_called_once_with(
+            _amphora_mock, _amphora_mock.vrrp_ip,
+            timeout_dict=timeout_dict)
 
         # Test revert
         mock_driver.reset_mock()
@@ -580,8 +581,10 @@ class TestAmphoraDriverTasks(base.TestCase):
                                                mock_amphora_repo_update):
         amp_compute_conn_wait_obj = (
             amphora_driver_tasks.AmphoraComputeConnectivityWait())
-        amp_compute_conn_wait_obj.execute(_amphora_mock)
-        mock_driver.get_info.assert_called_once_with(_amphora_mock)
+        amp_compute_conn_wait_obj.execute(_amphora_mock,
+                                          raise_retry_exception=True)
+        mock_driver.get_info.assert_called_once_with(
+            _amphora_mock, raise_retry_exception=True)
 
         mock_driver.get_info.side_effect = driver_except.TimeOutException()
         self.assertRaises(driver_except.TimeOutException,
